<?php
/**
 * Marathi language file
 *
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['menu']                  = 'कॉन्फिगरेशन सेटिंग';
$lang['error']                 = 'चुकीचा शब्द टाकल्यामुळे सेटिंग अद्ययावत केलेली नाहीत. कृपया तुमचे बदल परत तपासा आणि परत सबमिट करा. <br /> चुकीच्या शब्दांभोवती लाल बॉर्डर दाखवली जाईल.';
$lang['updated']               = 'सेटिंग अद्ययावत केली आहेत.';
$lang['nochoice']              = '( इतर काही पर्याय नाहीत )';
$lang['locked']                = 'सेटिंगची फाइल अद्ययावत करू शकलो नाही. जर हे सहेतुक नसेल तर, <br />
सेटिंग च्या फाइल चे नाव व त्यावरील परवानग्या बरोबर असल्याची खात्री करा.';
$lang['danger']                = 'सावधान : हा पर्याय बदलल्यास तुमची विकी आणि तिचे कॉनफिगरेशन निकामी होऊ शकते.';
$lang['warning']               = 'सावघान: येथील पर्याय बदल्यास, अनपेक्षीत गोष्टी होऊ शकतात.';
$lang['security']              = 'सुरक्षा संबंधी सूचना : हा पर्याय बदलल्यास तुमची साईट असुरक्षित होऊ शकते.';
$lang['_configuration_manager'] = 'कॉन्फिगरेशन व्यवस्थापक';
$lang['_header_dokuwiki']      = 'डॉक्युविकि सेटिंग';
$lang['_header_plugin']        = 'प्लगिन सेटिंग';
$lang['_header_template']      = 'टेम्पलेट (नमुना) सेटिंग';
$lang['_header_undefined']     = 'अनिश्चित सेटिंग';
$lang['_basic']                = 'पायाभूत सेटिंग';
$lang['_display']              = 'डिसप्ले सेटिंग';
$lang['_authentication']       = 'अधिकृत करण्याविषयी सेटिंग';
$lang['_anti_spam']            = 'भंकस-विरोधी सेटिंग';
$lang['_editing']              = 'संपादन सेटिंग';
$lang['_links']                = 'लिंक सेटिंग';
$lang['_media']                = 'दृक्श्राव्य माध्यम सेटिंग';
$lang['_advanced']             = 'सविस्तर सेटिंग';
$lang['_network']              = 'नेटवर्क सेटिंग';
$lang['_msg_setting_undefined'] = 'सेटिंगविषयी उप-डेटा उपलब्ध नाही.';
$lang['_msg_setting_no_class'] = 'सेटिंगचा क्लास उपलब्ध नाही';
$lang['_msg_setting_no_default'] = 'आपोआप किम्मत नाही';
$lang['fmode']                 = 'फाइल निर्मिती मोड';
$lang['dmode']                 = 'डिरेक्टरी निर्मिती मोड';
$lang['lang']                  = 'भाषा';
$lang['basedir']               = 'पायाभूत डिरेक्टरी';
$lang['baseurl']               = 'पायाभूत URL';
$lang['savedir']               = 'डेटा साठवण्यासाठीची डिरेक्टरी';
$lang['start']                 = 'सुरुवातीच्या पानाचे नाव';
$lang['title']                 = 'विकीचे शीर्षक';
$lang['template']              = 'नमुना';
$lang['license']               = 'कुठल्या लायसंसच्या अंतर्गत तुमचा मजकूर रिलीज़ केला गेला पाहिजे ?';
$lang['fullpath']              = 'पानांचा पूर्ण पत्ता फूटर मधे दाखव';
$lang['recent']                = 'अलीकडील बदल';
$lang['breadcrumbs']           = 'ब्रेडक्रम्बची संख्या';
$lang['youarehere']            = 'प्रतवार ब्रेडक्रम्ब';
$lang['typography']            = 'अनवधानाने झालेल्या चुका बदला';
$lang['htmlok']                = 'अंतर्गत HTML टाकायची परवानगी असू दे';
$lang['phpok']                 = 'अंतर्गत PHP टाकायची परवानगी असू दे';
$lang['dformat']               = 'दिनांकाची पद्धत ( PHP चं <a href="http://php.net/strftime">strftime</a> हे फंक्शन पाहा )';
$lang['signature']             = 'हस्ताक्षर';
$lang['toptoclevel']           = 'अनुक्रमणिकेची सर्वोच्च पातळी';
$lang['tocminheads']           = 'कमीत कमी किती शीर्षके असल्यास अनुक्रमणिका बनवावी';
$lang['maxtoclevel']           = 'अनुक्रमणिकेची जास्तीत जास्त पातळी  ';
$lang['maxseclevel']           = 'विभागीय संपादनाची जास्तीतजास्त पातळी';
$lang['camelcase']             = 'लिंकसाठी कॅमलकेस वापरा.';
$lang['deaccent']              = 'सरळ्सोट पृष्ठ नाम';
$lang['useheading']            = 'पहिलं शीर्षक पृष्ठ नाम म्हणुन वापरा';
$lang['refcheck']              = 'दृक्श्राव्य माध्यमाचा संदर्भ तपासा';
$lang['allowdebug']            = 'डिबगची परवानगी <b> गरज नसल्यास बंद ठेवा !</b>';
$lang['usewordblock']          = 'भंकस मजकूर थोपवण्यासाठी शब्दसमुह वापरा';
$lang['indexdelay']            = 'सूचीकरणापूर्वीचा अवकाश ( सेकंदात )';
$lang['relnofollow']           = 'बाह्य लिन्कसाठी rel=nofollow  वापरा';
$lang['mailguard']             = 'ईमेल दुर्बोध करा';
$lang['iexssprotect']          = 'अपलोड केलेल्या फाइल हानिकारक जावास्क्रिप्ट किंवा HTML साठी तपासा';
$lang['showuseras']            = 'पानाचं शेवटचं संपादन करणार्या सदस्याला काय दाखवायचं';
$lang['useacl']                = 'ACL  वापरा';
$lang['autopasswd']            = 'पासवर्ड आपोआप बनवा';
$lang['authtype']              = 'अधिकृत करण्याच्या व्यवस्थेचे बॅक-एंड';
$lang['passcrypt']             = 'पासवर्ड गुप्त ठेवण्याची पद्धत';
$lang['defaultgroup']          = 'डिफॉल्ट गट';
$lang['superuser']             = 'सुपर सदस्य - गट, सदस्य किंवा स्वल्पविरामाने अलग केलेली यादी ( उदा. सदस्य१, गट१, सदस्य२ ) ज्यांना ACL च्या सेटिंग व्यतिरिक्त सर्व पानांवर पूर्ण हक्क असतो.';
$lang['manager']               = 'व्यवस्थापक - गट, सदस्य किंवा स्वल्पविरामाने अलग केलेली यादी ( उदा. सदस्य१, गट१, सदस्य२ ) ज्यांना व्यवस्थापनाच्या निवडक सुविधा उपलब्ध असतात.';
$lang['profileconfirm']        = 'प्रोफाइल मधील बदल पासवर्ड वापरून नक्की करा';
$lang['disableactions']        = 'डॉक्युविकीच्या क्रिया बंद ठेवा';
$lang['disableactions_check']  = 'तपासा';
$lang['disableactions_subscription'] = 'सब्सक्राईब / अन्-सब्सक्राईब';
$lang['disableactions_wikicode'] = 'स्त्रोत पहा / कच्च्या स्वरूपात एक्सपोर्ट करा';
$lang['disableactions_other']  = 'इतर क्रिया ( स्वल्पविरामाने अलग केलेल्या )';
$lang['sneaky_index']          = 'सूची दृश्यामधे डिफॉल्ट स्वरूपात डॉक्युविकी सगळे नेमस्पेस दाखवते. हा पर्याय चालू केल्यास सदस्याला वाचण्याची परवानगी नसलेले नेमस्पेस दिसणार नाहीत. यामुळे परवानगी असलेले उप - नेमस्पेस न दिसण्याची शक्यता आहे. यामुळे काही विशिष्ठ ACL सेटिंगसाठी सूची वापरता येण्यासारखी राहणार नाही.';
$lang['auth_security_timeout'] = 'अधिकृत करण्याच्या प्रक्रियेची कालमर्यादा';
$lang['securecookie']          = 'HTTPS वापरून सेट केलेले कूकीज ब्राउजरने HTTPS द्वाराच पाठवले पाहिजेत का? जर तुमच्या विकीचं फ़क्त लॉगिन पानच SSL वापरून सुरक्षित केलं असेल व पानांचं ब्राउजिंग असुरक्षित असेल तर हा पर्याय चालू करू नका.';
$lang['updatecheck']           = 'अपडेट आणि सुरक्षिततेविशयी सूचनान्वर पाळत ठेऊ का? या सुविधेसाठी डॉक्युविकीला update.dokuwiki.org शी संपर्क साधावा लागेल.';
$lang['userewrite']            = 'छान छान URL वापर';
$lang['useslash']              = 'URL  मधे नेमस्पेस अलग करण्यासाठी \'/\' चिह्न वापरा';
$lang['usedraft']              = 'संपादन करताना मसुदा आपोआप सुरक्षित करा';
$lang['sepchar']               = 'पानाच्या नावातील शब्द अलग करण्याचे चिह्न';
$lang['canonical']             = 'पूर्णपणे सुटसुटीत URL वापरा';
$lang['autoplural']            = 'लिंकमधिल अनेकवचने तपासा';
$lang['compression']           = 'अडगळीतल्या फाइल संकुचित करण्याची पद्धत';
$lang['cachetime']             = 'कॅशचे जास्तीतजास्त वयोमान ( सेकंदात )';
$lang['locktime']              = 'लॉक फाइलचे जास्तीतजास्त वयोमान ( सेकंदात )';
$lang['fetchsize']             = 'बाह्य स्त्रोताकडून जास्तीतजास्त किती डाउनलोड fecth.php  करू शकतो ( बाइट्स मधे )';
$lang['notify']                = 'बदलाच्या सूचना ह्या ईमेल वर पाठवा';
$lang['registernotify']        = 'नवीन नोंदणी केलेल्या सदस्यांची माहिती ह्या ईमेल वर पाठवा';
$lang['mailfrom']              = 'आपोआप ईमेल पाठवण्यासाठी वापरायचा ईमेल';
$lang['gzip_output']           = 'xhtml साठी gzip Content-encoding  वापरा';
$lang['gdlib']                 = 'gzip लायब्ररीची आवृत्ती';
$lang['im_convert']            = 'ImageMagik च्या परिवर्तन करणार्या टूलचा पाथ';
$lang['jpg_quality']           = 'JPG संकुचित करण्याचा दर्जा ( १ - १०० )';
$lang['subscribers']           = 'पानाची पुरवणी देण्याची सुविधा चालू करा';
$lang['compress']              = 'CSS आणि जावास्क्रिप्टचे आउट्पुट संकुचित करा';
$lang['hidepages']             = 'समान पाने लपवा';
$lang['send404']               = 'अस्तित्वात नसलेल्या पानांसाठी "HTTP 404/Page not found" संदेश पाठवा';
$lang['sitemap']               = 'गूगल साईट-मॅप बनवा';
$lang['broken_iua']            = 'ignore_user_abort फंक्शन तुमच्या सिस्टम वर चालत नाही का? यामुळे शोध सूची निकामी होऊ शकते. IIS + PHP/CGI वर हे काम करत नाही हे नक्की झाले आहे. अधिक माहितीसाठी <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">बग ८५२</a> पहा.';
$lang['xsendfile']             = 'सर्वर कडून स्थिर फाइल पाठवली जाण्यासाठी X-Sendfile शीर्षक ( header ) वापरू का ? तुमच्या वेब सर्वर मधे ही सुविधा असली पाहिजे.';
$lang['renderer_xhtml']        = 'मुख्य ( xhtml ) विकी आउट्पुट साथी वापरायचा चित्रक ( renderer )';
$lang['renderer__core']        = '%s (डॉक्युविकीचा मूलभूत)';
$lang['renderer__plugin']      = '%s (प्लगिन)';
$lang['rememberme']            = 'कायमच्या लॉगिन कुकीजला परवानगी दया ( लक्षात ठेवा )';
$lang['rss_type']              = 'XML पुरवणीचा प्रकार';
$lang['rss_linkto']            = 'XML पुरवणीची लिंक येथे जाते';
$lang['rss_content']           = 'XML पुरवणीतल्या मुद्द्यामधे काय काय दाखवायचं?';
$lang['rss_update']            = 'XML पुरवणी अद्ययावत करण्याचा कालखंड ( सेकंदात )';
$lang['recent_days']           = 'किती अलीकडील बदल ठेवायचे? ( दिवसात )';
$lang['rss_show_summary']      = 'XML पुरावानीच्या शीर्षकात सारांश दाखवा';
$lang['target____wiki']        = 'अंतर्गत लिंकसाठीची विंडो';
$lang['target____interwiki']   = 'आंतरविकि लिंकसाठीची विंडो';
$lang['target____extern']      = 'बाह्य लिंकसाठीची विंडो';
$lang['target____media']       = 'दृक्श्राव्य लिंकसाठीची विंडो';
$lang['target____windows']     = 'विंडो लिंकसाठीची विंडो';
$lang['proxy____host']         = 'छद्म ( proxy ) सर्वरचे नाव';
$lang['proxy____port']         = 'छद्म ( proxy ) सर्वरचे पोर्ट';
$lang['proxy____user']         = 'छद्म ( proxy ) सर्वरचे सदस्यनाम';
$lang['proxy____pass']         = 'छद्म ( proxy ) सर्वरचा पासवर्ड';
$lang['proxy____ssl']          = 'छद्म सर्वरला संपर्क साधण्यासाठी SSL वापरा';
$lang['license_o_']            = 'काही निवडले नाही';
$lang['typography_o_0']        = 'काही नाही';
$lang['typography_o_1']        = 'फक्त दुहेरी अवतरण चिह्न';
$lang['typography_o_2']        = 'सर्व प्रकारची अवतरण चिन्हे ( नेहेमी चालेलच असं नाही )';
$lang['userewrite_o_0']        = 'कुठेही नाही';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'डॉक्युविकी अंतर्गत';
$lang['deaccent_o_0']          = 'बंद';
$lang['deaccent_o_1']          = 'एक्सेंट काढून टाका';
$lang['deaccent_o_2']          = 'रोमन लिपित बदला';
$lang['gdlib_o_0']             = 'GD Lib  उपलब्ध नाही';
$lang['gdlib_o_1']             = 'आवृत्ती १.x';
$lang['gdlib_o_2']             = 'आपोआप ओळखा';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'सारांश';
$lang['rss_content_o_diff']    = 'एकत्रित फरक';
$lang['rss_content_o_htmldiff'] = 'HTML पद्धतीचा फरकांचा तक्ता';
$lang['rss_content_o_html']    = 'पानाचा पूर्ण HTML मजकूर';
$lang['rss_linkto_o_diff']     = 'फरक दृश्य';
$lang['rss_linkto_o_page']     = 'उजळणी केलेले पान';
$lang['rss_linkto_o_rev']      = 'आवृत्त्यांची यादी';
$lang['rss_linkto_o_current']  = 'सद्य पान';
$lang['compression_o_0']       = 'काही नाही';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'वापरू नका';
$lang['xsendfile_o_1']         = 'lighttpd चा प्रोप्रायटरी शीर्षक (हेडर)';
$lang['xsendfile_o_2']         = 'स्टॅण्डर्ड X-sendfile शीर्षक';
$lang['xsendfile_o_3']         = ' Nginx चा प्रोप्रायटरी Accel-Redirect शीर्षक';
$lang['showuseras_o_loginname'] = 'लॉगिन  नाम';
$lang['showuseras_o_username'] = 'सदस्याचे पूर्ण नाव';
$lang['showuseras_o_email']    = 'सदस्याचा ईमेल ( मेल सुरक्षिततेच्या सेटिंग अनुसार दुर्बोध केलेला ) ';
$lang['showuseras_o_email_link'] = 'सदस्याचा ईमेल maito: लिंक   स्वरूपात';
$lang['useheading_o_0']        = 'कधीच नाही';
$lang['useheading_o_navigation'] = 'फ़क्त मार्गदर्शन';
$lang['useheading_o_content']  = 'फ़क्त विकी मजकूर';
$lang['useheading_o_1']        = 'नेहमी';
